@@ -39,10 +39,13 @@
 //
 //M*/
 
+#include <iostream>
+#include <opencv2/opencv_modules.hpp>
+
+#ifdef HAVE_OPENCV_TEXT
+
 #include "opencv2/datasets/tr_icdar.hpp"
-
 #include <opencv2/core.hpp>
-
 #include "opencv2/text.hpp"
 #include "opencv2/imgproc.hpp"
 #include "opencv2/imgcodecs.hpp"
@@ -50,8 +53,6 @@
 #include <cstdio>
 #include <cstdlib> // atoi
 
-#include <iostream>
-
 #include <string>
 #include <vector>
 
@@ -279,7 +280,7 @@ int main(int argc, char *argv[])
             ocr->run(grey, group_img, output, &boxes, &words, &confidences, OCR_LEVEL_WORD);
 
             output.erase(remove(output.begin(), output.end(), '\n'), output.end());
-            //cout << "OCR output = \"" << output << "\" lenght = " << output.size() << endl;
+            //cout << "OCR output = \"" << output << "\" length = " << output.size() << endl;
 
             if (output.size() < 3)
                 continue;
@@ -509,3 +510,13 @@ int main(int argc, char *argv[])
 
     return 0;
 }
+
+#else
+
+int main()
+{
+    std::cerr << "OpenCV was built without text module" << std::endl;
+    return 0;
+}
+
+#endif // HAVE_OPENCV_TEXT
